export interface ContainerSizes {
    sm: '540px';
    md: '720px';
    lg: '960px';
    xl: '1200px';
}
export interface MediaBreakpoints {
    sm: '576px';
    md: '768px';
    lg: '992px';
    xl: '1240px';
}
export interface Font {
    readonly family: {
        secondary: 'HK Grotesk';
    };
    readonly bold: '700';
    readonly size: {
        default: '18px';
    };
    readonly lineHeight: {
        default: '28px';
    };
    readonly typographyBreakpoint: '660px';
}
export interface Colors {
    readonly primary: {
        default: '#9df6df';
        light: '#e3fcf6';
        lighter: '#f5fffc';
        dark: '#57efc7';
    };
    readonly secondary: {
        default: '#167cef';
        light: '#5da3f4';
        dark: '#0c56ac';
    };
    readonly tertiary: {
        default: '#269b7c';
        light: '#3ed0a9';
        dark: '#175e4b';
    };
    readonly greys: {
        default: '#555555';
        light: '#eeeeee';
        lighter: '#f5f5f5';
        dark: '#222222';
        white: '#ffffff';
        mid: '#999999';
    };
    readonly error: {
        default: '#dc2c2c';
        light: '#e76e6e';
        dark: '#a21a1a';
    };
    readonly background: {
        default: '#ffffff';
        primary: '#e5fff7';
        secondary: '#f3f8fe';
    };
}
export interface Padding {
    base: '10px';
    small: '20px';
    medium: '20px';
    large: '50px';
}
export interface Border {
    width: '2px';
    radius: '4px';
}
export interface Form {
    element: {
        height: {
            small: '40px';
            default: '48px';
        };
        width: {
            default: '400px';
        };
    };
}
export interface Icon {
    sm: 24;
}
export interface ThemeInterface {
    border: Border;
    colors: Colors;
    containerSizes: ContainerSizes;
    font: Font;
    form: Form;
    icon: Icon;
    mediaBreakpoints: MediaBreakpoints;
    padding: Padding;
}
declare const theme: ThemeInterface;
export default theme;
